#[non_exhaustive]pub enum LocalizationState {
Unspecified,
NotApplicable,
Pending,
Completed,
UnknownValue(UnknownValue),
}Expand description
Status of localized text.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
Unspecified
Not used.
NotApplicable
Localization is not applicable for requested language. This can happen when:
- The requested language was not supported by Advisory Notifications at the time of localization (including notifications created before the localization feature was launched).
- The requested language is English, so only the English text is returned.
Pending
Localization for requested language is in progress, and not ready yet.
Completed
Localization for requested language is completed.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using LocalizationState::value or LocalizationState::name.
Implementations