#[non_exhaustive]pub enum NotificationView {
Unspecified,
Basic,
Full,
UnknownValue(UnknownValue),
}Expand description
Notification view.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Not specified, equivalent to BASIC.
Basic
Server responses only include title, creation time and Notification ID. Note: for internal use responses also include the last update time, the latest message text and whether notification has attachments.
Full
Include everything.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using NotificationView::value or NotificationView::name.
Implementations