GetNotificationRequest

Struct GetNotificationRequest 

#[non_exhaustive]
pub struct GetNotificationRequest { pub name: String, pub language_code: String, /* private fields */ }
Request for fetching a notification.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Required. A name of the notification to retrieve. Format: organizations/{organization}/locations/{location}/notifications/{notification} or projects/{projects}/locations/{location}/notifications/{notification}.

language_code: String

ISO code for requested localization language. If unset, will be interpereted as “en”. If the requested language is valid, but not supported for this notification, English will be returned with an “Not applicable” LocalizationState. If the ISO code is invalid (i.e. not a real language), this RPC will throw an error.

Implementations

Source

impl GetNotificationRequest

pub fn new() -> Self

Creates a new default instance.

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = GetNotificationRequest::new().set_name("example");
pub fn set_language_code<T: Into<String>>(self, v: T) -> Self

Sets the value of language_code.

Example
let x = GetNotificationRequest::new().set_language_code("example");