#[non_exhaustive]pub struct ListNotificationsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub view: NotificationView,
pub language_code: String,
/* private fields */
}Expand description
Request for fetching all notifications for a given parent.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The parent, which owns this collection of notifications. Must be of the form “organizations/{organization}/locations/{location}” or “projects/{project}/locations/{location}”.
page_size: i32The maximum number of notifications to return. The service may return fewer than this value. If unspecified or equal to 0, at most 50 notifications will be returned. The maximum value is 50; values above 50 will be coerced to 50.
page_token: StringA page token returned from a previous request. When paginating, all other parameters provided in the request must match the call that returned the page token.
view: NotificationViewSpecifies which parts of the notification resource should be returned in the response.
language_code: StringISO code for requested localization language. If unset, will be interpereted as “en”. If the requested language is valid, but not supported for this notification, English will be returned with an “Not applicable” LocalizationState. If the ISO code is invalid (i.e. not a real language), this RPC will throw an error.
Implementations
Sourceimpl ListNotificationsRequest
impl ListNotificationsRequest
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListNotificationsRequest::new().set_page_token("example");Sourcepub fn set_view<T: Into<NotificationView>>(self, v: T) -> Self
pub fn set_view<T: Into<NotificationView>>(self, v: T) -> Self
Sourcepub fn set_language_code<T: Into<String>>(self, v: T) -> Self
pub fn set_language_code<T: Into<String>>(self, v: T) -> Self
Sets the value of language_code.
Example
let x = ListNotificationsRequest::new().set_language_code("example");Trait Implementations
Sourceimpl Clone for ListNotificationsRequest
impl Clone for ListNotificationsRequest
Sourcefn clone(&self) -> ListNotificationsRequest
fn clone(&self) -> ListNotificationsRequest
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
source. Read more