#[non_exhaustive]pub struct GetNotificationRequest {
pub name: String,
pub language_code: String,
/* private fields */
}Expand description
Request for fetching a notification.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. A name of the notification to retrieve. Format: organizations/{organization}/locations/{location}/notifications/{notification} or projects/{projects}/locations/{location}/notifications/{notification}.
language_code: StringISO code for requested localization language. If unset, will be interpereted as “en”. If the requested language is valid, but not supported for this notification, English will be returned with an “Not applicable” LocalizationState. If the ISO code is invalid (i.e. not a real language), this RPC will throw an error.
Implementations
Sourceimpl GetNotificationRequest
impl GetNotificationRequest